/// <reference types="node" />
import { EventEmitter } from 'events';
import { Redactor } from './strings';
import { severities } from './types';
import type { ILogger, LogLevel } from './types';
export declare const LOG_DELIMITER = "___$LAMBDA-LOG-TAG$___";
declare type Handler = Function;
export declare type Formatter = (context: FormatContext, severity: typeof severities[number], ...args: unknown[]) => string;
export declare type Loggable = string | boolean | number;
export interface LoggerWithSub extends ILogger {
    createSubLogger: (name: string) => LoggerWithSub;
}
export interface LambdaLogger extends LoggerWithSub {
    handler: Handler;
    setMinimumLogLevel: (level: LogLevel) => void;
    events: EventEmitter;
    setKey: (key: string, val: Loggable | (() => Loggable)) => void;
}
export interface FormatContext {
    keys: Record<string, Loggable>;
    contextPath: string[];
}
export interface LoggerProps {
    /** Hide log entries of lower severity */
    minimumLogLevel?: LogLevel;
    /** Function that formats the log message; receives the logContext, severity, and the N-arity log arguments */
    formatter?: Formatter;
    /** add a Bearer token redactor. Default true */
    useBearerRedactor?: boolean;
    /** setup global handlers for uncaughtException and unhandledRejection. Only one logger per-lambda can use this option. */
    useGlobalErrorHandler?: boolean;
    forceGlobalErrorHandler?: boolean;
    redactors?: (Redactor | string | RegExp)[];
    testMode?: boolean;
}
export declare function Logger({ minimumLogLevel, formatter, useBearerRedactor, useGlobalErrorHandler, forceGlobalErrorHandler, redactors, testMode, }?: LoggerProps): LambdaLogger;
export {};
