"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.wrapper = void 0;
const types_1 = require("./types");
// eslint-disable-next-line @typescript-eslint/no-empty-function
const noop = () => { };
function wrapper(baseLogger) {
    const logger = baseLogger || {};
    if (logger.minimumLogLevel !== undefined &&
        !types_1.logLevels.includes(logger.minimumLogLevel)) {
        throw new Error(`"minimumLogLevel" must be one of: ${types_1.logLevels.join(', ')} or "undefined"`);
    }
    return {
        debug: wrapLogFn(logger, 'debug'),
        info: wrapLogFn(logger, 'info'),
        warn: wrapLogFn(logger, 'warn'),
        error: wrapLogFn(logger, 'error'),
    };
}
exports.wrapper = wrapper;
function wrapLogFn(logger, prop) {
    let func;
    const logFn = logger[prop];
    if (logFn && typeof logFn === 'function') {
        func = logFn;
    }
    else {
        func =
            logger.minimumLogLevel !== undefined
                ? // eslint-disable-next-line no-console
                    (console[prop] || console.log).bind(console)
                : noop;
    }
    return (...args) => {
        // Level is an alias for INFO to support console.log drop-in
        if (logger.minimumLogLevel !== undefined &&
            types_1.logLevels.indexOf(logger.minimumLogLevel) >
                types_1.logLevels.indexOf(prop.toUpperCase())) {
            return;
        }
        return func(...args);
    };
}
